package Bundle::SDK::COG;

use warnings;
use strict;

=head1 NAME

Bundle::SDK::COG - CPAN Bundle for modules COG uses

=cut

our $VERSION = '0.04';

=head1 SYNOPSIS

cpan Bundle::SDK::COG

=head1 CONTENTS

Bundle::CPAN

Bundle::Test

Test::Pod::Coverage

Bundle::COG

Astro::MoonPhase

CPAN::Mini

Date::DayOfWeek

Module::Starter

Perl::Tidy

Spork

Time::HiRes

WWW::Mechanize

Devel::Cover

App::Ack

Catalyst::Devel

Catalyst::Runtime

DBD::mysql

DBI

Data::Dump

DateTime

File::Compare

File::RandomLine

Getopt::Euclid

Getopt::Std

HTML::TagCloud

IO::Socket

JSON

List::Util

List::MoreUtils

Log::Log4perl

Net::Twitter

Perl::Critic

Perl6::Say

Perl6::Slurp

Pod::Coverage

Pod::Webserver

Regexp::Common

Smart::Comments

Spreadsheet::ParseExcel

Test::Perl::Critic

Test::Pod

XML::Simple

YAML

=head1 AUTHOR

Jose Castro, C<< <cog@cpan.org> >>

=head1 ACKNOWLEDGEMENTS

I got the idea for this very useful (to me) Bundle out of Simon's
Bundle::SDK::SIMON. Apart from saving me much time whenever I go to a
new machine, it can also serve as a way to show others what I'm using.

I got the nerve to do it after reading this:
http://use.perl.org/~Ovid/journal/26818. Afterall, "What is the CPAN
for?"

=head1 COPYRIGHT & LICENSE

Copyright 2005 Jose Castro, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Bundle::SDK::COG
